==> react-native-ui-view-0.1.2.tgz: package/esm/components/Portal/host.js <==
import React, { useEffect, useState } from 'react';
import { DeviceEventEmitter, View, StyleSheet } from 'react-native';
const addEventKey = 'REACT_NATIVE_UI_VIEW_ADD_PORTAL';
const removeEventKey = 'REACT_NATIVE_UI_VIEW_REMOVE_PORTAL';
const eventEmitter = DeviceEventEmitter;
export class PortalGuard {
    constructor() {
        this.key = 100;
    }
    add(elem) {
        const key = this.key++;
        eventEmitter.emit(addEventKey, { elem, key });
        return key;
    }
    remove(key) {
        eventEmitter.emit(removeEventKey, key);
    }
}
export const PortalHost = () => {
    const [portalList, setPortalList] = useState([]);
    const mount = (portalItem) => {
        setPortalList([...portalList, portalItem]);
    };
    const unmount = (key) => {
        setPortalList([...portalList].filter(item => item.key !== key));
    };
    useEffect(() => {
        const listenerAdd = eventEmitter.addListener(addEventKey, mount);
        const listenerRemove = eventEmitter.addListener(removeEventKey, unmount);
        return () => {
            listenerAdd.remove();
            listenerRemove.remove();
        };
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, []);
    return (React.createElement(React.Fragment, null, portalList.map(item => (React.createElement(View, { style: styles.portal, key: item.key, pointerEvents: "box-none" }, item.elem)))));
};
const styles = StyleSheet.create({
    portal: {
        position: 'absolute',
        left: 0,
        top: 0,
        right: 0,
        bottom: 0,
    },
});

==> react-native-ui-view-0.1.3.tgz: package/esm/components/Portal/host.js <==
import React, { useEffect, useState } from 'react';
import { DeviceEventEmitter, View, StyleSheet } from 'react-native';
const addEventKey = 'REACT_NATIVE_UI_VIEW_ADD_PORTAL';
const removeEventKey = 'REACT_NATIVE_UI_VIEW_REMOVE_PORTAL';
const eventEmitter = DeviceEventEmitter;
export class PortalGuard {
    constructor() {
        this.key = 100;
    }
    add(elem) {
        const key = this.key++;
        eventEmitter.emit(addEventKey, { elem, key });
        return key;
    }
    remove(key) {
        eventEmitter.emit(removeEventKey, key);
    }
}
export const PortalHost = () => {
    const [portalList, setPortalList] = useState([]);
    const mount = (portalItem) => {
        setPortalList([...portalList, portalItem]);
    };
    const unmount = (key) => {
        setPortalList([...portalList].filter(item => item.key !== key));
    };
    useEffect(() => {
        const listenerAdd = eventEmitter.addListener(addEventKey, mount);
        const listenerRemove = eventEmitter.addListener(removeEventKey, unmount);
        return () => {
            listenerAdd.remove();
            listenerRemove.remove();
        };
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, []);
    return (React.createElement(React.Fragment, null, portalList.map(item => (React.createElement(View, { style: [styles.portal, { zIndex: item.key }], key: item.key, pointerEvents: "box-none" }, item.elem)))));
};
const styles = StyleSheet.create({
    portal: {
        position: 'absolute',
        left: 0,
        top: 0,
        right: 0,
        bottom: 0,
    },
});
